@@ -128,11 +128,12 @@ dconf_settings_backend_send (DConfSettingsBackend *dcsb,
                              gpointer              user_data)
 {
   GDBusConnection *connection;
-  GError *error = NULL;
   gint i;
 
   for (i = 0; i < dcem->n_messages; i++)
     {
+      GError *error = NULL;
+
       switch (dcem->bus_types[i])
         {
         case 'e':
@@ -176,7 +177,14 @@ dconf_settings_backend_send (DConfSettingsBackend *dcsb,
         }
 
       if (connection == NULL && callback != NULL)
-        callback (NULL, NULL, user_data);
+        {
+          g_assert (error != NULL);
+
+          g_warning ("%s", error->message);
+          g_error_free (error);
+
+          callback (NULL, NULL, user_data);
+        }
 
       if (connection != NULL)
         g_dbus_connection_call (connection,
@@ -194,11 +202,29 @@ static GVariant *
 dconf_settings_backend_send_finish (GObject      *source,
                                     GAsyncResult *result)
 {
+  GError *error = NULL;
+  GVariant *reply;
+
   if (source == NULL)
     return NULL;
 
-  return g_dbus_connection_call_finish (G_DBUS_CONNECTION (source),
-                                        result, NULL);
+  reply = g_dbus_connection_call_finish (G_DBUS_CONNECTION (source),
+                                         result, &error);
+
+  if (reply == NULL)
+    {
+      /* This should only be hit in the case that something is seriously
+       * wrong with the installation (ie: the service can't be started,
+       * etc).  Bug #641768 requests some notification of these kinds of
+       * situations in the context of the gsettings(1) commandline tool,
+       * so a g_warning() is appropriate here.
+       */
+
+      g_warning ("%s", error->message);
+      g_error_free (error);
+    }
+
+  return reply;
 }
 
 struct _Outstanding
@@ -633,23 +659,9 @@ dconf_settings_backend_sync (GSettingsBackend *backend)
   g_static_mutex_unlock (&dcsb->lock);
 }
 
-static GVariant *
-dconf_settings_backend_service_func (DConfEngineMessage *dcem)
-{
-  g_assert (dcem->bus_types[0] == 'e');
-
-  return g_dbus_connection_call_sync (g_bus_get_sync (G_BUS_TYPE_SESSION,
-                                                      NULL, NULL),
-                                      dcem->bus_name, dcem->object_path,
-                                      dcem->interface_name, dcem->method_name,
-                                      dcem->parameters[0], dcem->reply_type,
-                                      0, -1, NULL, NULL);
-}
-
 static void
 dconf_settings_backend_init (DConfSettingsBackend *dcsb)
 {
-  dconf_engine_set_service_func (dconf_settings_backend_service_func);
   dcsb->engine = dconf_engine_new (NULL);
 }
 
